# plrs <a href="https://pypi.org/project/plrs/">![Version](https://img.shields.io/pypi/v/plrs)</a>
The multi-tool of lexical analysis and tokenization.

# Install
```
pip install plrs
```

# Build
```
maturin build
```
